"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.mdb.kafka.v1.cluster_pb2
import yandex.cloud.mdb.kafka.v1.maintenance_pb2
import yandex.cloud.mdb.kafka.v1.topic_pb2
import yandex.cloud.mdb.kafka.v1.user_pb2
import yandex.cloud.operation.operation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® Cluster resource to return.

    To get the cluster ID, make a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list Apache Kafka® clusters in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClustersResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.

    To get the next page of results, set [page_token] to the [ListClustersResponse.next_page_token] returned by the previous list request.
    """
    filter: builtins.str
    """Filter support is not currently implemented. Any filters are ignored."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token that allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClustersRequest.page_size], use [next_page_token] as the value for the [ListClustersRequest.page_token] parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.kafka.v1.cluster_pb2.Cluster]:
        """List of Apache Kafka® clusters."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    TOPIC_SPECS_FIELD_NUMBER: builtins.int
    USER_SPECS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create the Apache Kafka® cluster in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the Apache Kafka® cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the Apache Kafka® cluster."""
    environment: yandex.cloud.mdb.kafka.v1.cluster_pb2.Cluster.Environment.ValueType
    """Deployment environment of the Apache Kafka® cluster."""
    network_id: builtins.str
    """ID of the network to create the Apache Kafka® cluster in."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Apache Kafka® cluster as `key:value` pairs.

        For example, "project": "mvp" or "source": "dictionary".
        """

    @property
    def config_spec(self) -> yandex.cloud.mdb.kafka.v1.cluster_pb2.ConfigSpec:
        """Kafka and hosts configuration the Apache Kafka® cluster."""

    @property
    def topic_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.kafka.v1.topic_pb2.TopicSpec]:
        """One or more configurations of topics to be created in the Apache Kafka® cluster."""

    @property
    def user_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.kafka.v1.user_pb2.UserSpec]:
        """Configurations of accounts to be created in the Apache Kafka® cluster."""

    @property
    def subnet_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of subnets to create brokers in."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups to place VMs of cluster on."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: yandex.cloud.mdb.kafka.v1.cluster_pb2.Cluster.Environment.ValueType = ...,
        config_spec: yandex.cloud.mdb.kafka.v1.cluster_pb2.ConfigSpec | None = ...,
        topic_specs: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.topic_pb2.TopicSpec] | None = ...,
        user_specs: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.user_pb2.UserSpec] | None = ...,
        network_id: builtins.str = ...,
        subnet_id: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        maintenance_window: yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec", "maintenance_window", b"maintenance_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "host_group_ids", b"host_group_ids", "labels", b"labels", "maintenance_window", b"maintenance_window", "name", b"name", "network_id", b"network_id", "security_group_ids", b"security_group_ids", "subnet_id", b"subnet_id", "topic_specs", b"topic_specs", "user_specs", b"user_specs"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to update.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    description: builtins.str
    """New description of the Apache Kafka® cluster."""
    name: builtins.str
    """New name for the Apache Kafka® cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Apache Kafka® cluster as `key:value` pairs.

        For example, "project": "mvp" or "source": "dictionary".

        The new set of labels will completely replace the old ones.
        To add a label, request the current set with the [ClusterService.Get] method, then send an [ClusterService.Update] request with the new label added to the set.
        """

    @property
    def config_spec(self) -> yandex.cloud.mdb.kafka.v1.cluster_pb2.ConfigSpec:
        """New configuration and resources for hosts in the Apache Kafka® cluster.

        Use [update_mask] to prevent reverting all cluster settings that are not listed in [config_spec] to their default values.
        """

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceWindow:
        """New maintenance window settings for the cluster."""

    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of subnets where the hosts are located or a new host is being created"""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_spec: yandex.cloud.mdb.kafka.v1.cluster_pb2.ConfigSpec | None = ...,
        name: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        maintenance_window: yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec", "maintenance_window", b"maintenance_window", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "maintenance_window", b"maintenance_window", "name", b"name", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids", "update_mask", b"update_mask"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to delete.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class ListClusterLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    COLUMN_FILTER_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ALWAYS_NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to request logs for.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterLogsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.

    To get the next page of results, set [page_token] to the [ListClusterLogsResponse.next_page_token] returned by the previous list request.
    """
    always_next_page_token: builtins.bool
    """The flag that defines behavior of providing the next page token.

    If this flag is set to `true`, this API method will always return [ListClusterLogsResponse.next_page_token], even if current page is empty.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name to filter by. Currently filtering can be applied to the `hostname` field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 1-63 characters long and match the regular expression `[a-z0-9.-]{1,61}`.

    Example of a filter: `message.hostname='node1.db.cloud.yandex.net'`
    """
    @property
    def column_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Columns from the logs table to request.

        If no columns are specified, full log records are returned.
        """

    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the logs request."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End timestamp for the logs request."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        column_filter: collections.abc.Iterable[builtins.str] | None = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        always_next_page_token: builtins.bool = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["always_next_page_token", b"always_next_page_token", "cluster_id", b"cluster_id", "column_filter", b"column_filter", "filter", b"filter", "from_time", b"from_time", "page_size", b"page_size", "page_token", b"page_token", "to_time", b"to_time"]) -> None: ...

global___ListClusterLogsRequest = ListClusterLogsRequest

@typing.final
class LogRecord(google.protobuf.message.Message):
    """A single log record."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MessageEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Log record timestamp."""

    @property
    def message(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Contents of the log record."""

    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        message: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "timestamp", b"timestamp"]) -> None: ...

global___LogRecord = LogRecord

@typing.final
class ListClusterLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token that allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterLogsRequest.page_size], use [next_page_token] as the value for the [ListClusterLogsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    This value is interchangeable with [StreamLogRecord.next_record_token] from StreamLogs method.
    """
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogRecord]:
        """Requested log records."""

    def __init__(
        self,
        *,
        logs: collections.abc.Iterable[global___LogRecord] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["logs", b"logs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterLogsResponse = ListClusterLogsResponse

@typing.final
class StreamLogRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_FIELD_NUMBER: builtins.int
    NEXT_RECORD_TOKEN_FIELD_NUMBER: builtins.int
    next_record_token: builtins.str
    """This token allows you to continue streaming logs starting from the exact same record.

    To continue streaming, specify value of [next_record_token] as value for [StreamClusterLogsRequest.record_token] parameter in the next StreamLogs request.

    This value is interchangeable with [ListClusterLogsResponse.next_page_token] from ListLogs method.
    """
    @property
    def record(self) -> global___LogRecord:
        """One of the requested log records."""

    def __init__(
        self,
        *,
        record: global___LogRecord | None = ...,
        next_record_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["record", b"record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["next_record_token", b"next_record_token", "record", b"record"]) -> None: ...

global___StreamLogRecord = StreamLogRecord

@typing.final
class StreamClusterLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    COLUMN_FILTER_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    RECORD_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    record_token: builtins.str
    """Record token.

    Set [record_token] to the [StreamLogRecord.next_record_token] returned by a previous [ClusterService.StreamLogs] request to start streaming from next log record.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name to filter by. Currently filtering can be applied to the `hostname` field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.

    Example of a filter: `message.hostname='node1.db.cloud.yandex.net'`
    """
    @property
    def column_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Columns from logs table to get in the response.

        If no columns are specified, full log records are returned.
        """

    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the logs request."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End timestamp for the logs request.

        If this field is not set, all existing logs will be sent and then the new ones as they appear.
        In essence it has `tail -f` semantics.
        """

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        column_filter: collections.abc.Iterable[builtins.str] | None = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        record_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "column_filter", b"column_filter", "filter", b"filter", "from_time", b"from_time", "record_token", b"record_token", "to_time", b"to_time"]) -> None: ...

global___StreamClusterLogsRequest = StreamClusterLogsRequest

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterOperationsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.

    To get the next page of results, set [page_token] to the [ListClusterOperationsResponse.next_page_token] returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token that allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterOperationsRequest.page_size], use [next_page_token] as the value for the [ListClusterOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified Apache Kafka® cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse

@typing.final
class ListClusterHostsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterHostsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.

    To get the next page of results, set [page_token] to the [ListClusterHostsResponse.next_page_token] returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterHostsRequest = ListClusterHostsRequest

@typing.final
class ListClusterHostsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token that allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterHostsRequest.page_size], use the [next_page_token] as the value for the [ListClusterHostsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.kafka.v1.cluster_pb2.Host]:
        """List of hosts."""

    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.cluster_pb2.Host] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterHostsResponse = ListClusterHostsResponse

@typing.final
class MoveClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to move.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    destination_folder_id: builtins.str
    """ID of the destination folder."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "destination_folder_id", b"destination_folder_id"]) -> None: ...

global___MoveClusterRequest = MoveClusterRequest

@typing.final
class MoveClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SOURCE_FOLDER_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster being moved."""
    source_folder_id: builtins.str
    """ID of the source folder."""
    destination_folder_id: builtins.str
    """ID of the destnation folder."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        source_folder_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "destination_folder_id", b"destination_folder_id", "source_folder_id", b"source_folder_id"]) -> None: ...

global___MoveClusterMetadata = MoveClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to start.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster to stop.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class RescheduleMaintenanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RescheduleType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RescheduleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RescheduleMaintenanceRequest._RescheduleType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RESCHEDULE_TYPE_UNSPECIFIED: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 0
        IMMEDIATE: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 1
        """Start the maintenance operation immediately."""
        NEXT_AVAILABLE_WINDOW: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 2
        """Start the maintenance operation within the next available maintenance window."""
        SPECIFIC_TIME: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 3
        """Start the maintenance operation at the specific time."""

    class RescheduleType(_RescheduleType, metaclass=_RescheduleTypeEnumTypeWrapper): ...
    RESCHEDULE_TYPE_UNSPECIFIED: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 0
    IMMEDIATE: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 1
    """Start the maintenance operation immediately."""
    NEXT_AVAILABLE_WINDOW: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 2
    """Start the maintenance operation within the next available maintenance window."""
    SPECIFIC_TIME: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 3
    """Start the maintenance operation at the specific time."""

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESCHEDULE_TYPE_FIELD_NUMBER: builtins.int
    DELAYED_UNTIL_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kafka cluster to reschedule the maintenance operation for."""
    reschedule_type: global___RescheduleMaintenanceRequest.RescheduleType.ValueType
    """The type of reschedule request."""
    @property
    def delayed_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time until which this maintenance operation should be delayed. The value should be ahead of the first time when the maintenance operation has been scheduled for no more than two weeks. The value can also point to the past moment of time if [reschedule_type.IMMEDIATE] reschedule type is chosen."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        reschedule_type: global___RescheduleMaintenanceRequest.RescheduleType.ValueType = ...,
        delayed_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delayed_until", b"delayed_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "delayed_until", b"delayed_until", "reschedule_type", b"reschedule_type"]) -> None: ...

global___RescheduleMaintenanceRequest = RescheduleMaintenanceRequest

@typing.final
class RescheduleMaintenanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DELAYED_UNTIL_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kafka cluster."""
    @property
    def delayed_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time until which this maintenance operation is to be delayed."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        delayed_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delayed_until", b"delayed_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "delayed_until", b"delayed_until"]) -> None: ...

global___RescheduleMaintenanceMetadata = RescheduleMaintenanceMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/user_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/iam/v1/user_account.proto\x12\x13yandex.cloud.iam.v1\x1a\x1dyandex/cloud/validation.proto\"\xca\x01\n\x0bUserAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12V\n\x1cyandex_passport_user_account\x18\x02 \x01(\x0b\x32..yandex.cloud.iam.v1.YandexPassportUserAccountH\x00\x12\x41\n\x11saml_user_account\x18\x03 \x01(\x0b\x32$.yandex.cloud.iam.v1.SamlUserAccountH\x00\x42\x14\n\x0cuser_account\x12\x04\xc0\xc1\x31\x01\"A\n\x19YandexPassportUserAccount\x12\r\n\x05login\x18\x01 \x01(\t\x12\x15\n\rdefault_email\x18\x02 \x01(\t\"\x9f\x02\n\x0fSamlUserAccount\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x07name_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-256\x12H\n\nattributes\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.iam.v1.SamlUserAccount.AttributesEntry\x1a\x1a\n\tAttribute\x12\r\n\x05value\x18\x01 \x03(\t\x1a\x61\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..yandex.cloud.iam.v1.SamlUserAccount.Attribute:\x02\x38\x01\x42V\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.user_account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _USERACCOUNT.oneofs_by_name['user_account']._options = None
  _USERACCOUNT.oneofs_by_name['user_account']._serialized_options = b'\300\3011\001'
  _SAMLUSERACCOUNT_ATTRIBUTESENTRY._options = None
  _SAMLUSERACCOUNT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _SAMLUSERACCOUNT.fields_by_name['federation_id']._options = None
  _SAMLUSERACCOUNT.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _SAMLUSERACCOUNT.fields_by_name['name_id']._options = None
  _SAMLUSERACCOUNT.fields_by_name['name_id']._serialized_options = b'\350\3071\001\212\3101\0051-256'
  _globals['_USERACCOUNT']._serialized_start=95
  _globals['_USERACCOUNT']._serialized_end=297
  _globals['_YANDEXPASSPORTUSERACCOUNT']._serialized_start=299
  _globals['_YANDEXPASSPORTUSERACCOUNT']._serialized_end=364
  _globals['_SAMLUSERACCOUNT']._serialized_start=367
  _globals['_SAMLUSERACCOUNT']._serialized_end=654
  _globals['_SAMLUSERACCOUNT_ATTRIBUTE']._serialized_start=529
  _globals['_SAMLUSERACCOUNT_ATTRIBUTE']._serialized_end=555
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_start=557
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_end=654
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.video.v1.stream_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___GetStreamRequest = GetStreamRequest

@typing.final
class ListStreamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    page_size: builtins.int
    """The maximum number of the results per page to return. Default value: 100."""
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Possible fields: ["id", "title", "startTime", "finishTime", "createdAt", "updatedAt"]
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """Filter expression that filters resources listed in the response.
    Expressions are composed of terms connected by logic operators.
    Value in quotes: `'` or `"`
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["title", "lineId", "status"]
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListStreamsRequest = ListStreamsRequest

@typing.final
class ListStreamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAMS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def streams(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.stream_pb2.Stream]:
        """List of streams for channel."""

    def __init__(
        self,
        *,
        streams: collections.abc.Iterable[yandex.cloud.video.v1.stream_pb2.Stream] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "streams", b"streams"]) -> None: ...

global___ListStreamsResponse = ListStreamsResponse

@typing.final
class CreateStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ON_DEMAND_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    line_id: builtins.str
    """ID of the line."""
    title: builtins.str
    """Stream title."""
    description: builtins.str
    """Stream description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def on_demand(self) -> global___OnDemandParams:
        """On demand stream. It starts immediately when a signal appears."""

    @property
    def schedule(self) -> global___ScheduleParams:
        """Schedule stream. Determines when to start receiving the signal or finish time."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        on_demand: global___OnDemandParams | None = ...,
        schedule: global___ScheduleParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["on_demand", b"on_demand", "schedule", b"schedule", "stream_type", b"stream_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "description", b"description", "labels", b"labels", "line_id", b"line_id", "on_demand", b"on_demand", "schedule", b"schedule", "stream_type", b"stream_type", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["stream_type", b"stream_type"]) -> typing.Literal["on_demand", "schedule"] | None: ...

global___CreateStreamRequest = CreateStreamRequest

@typing.final
class OnDemandParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OnDemandParams = OnDemandParams

@typing.final
class ScheduleParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["finish_time", b"finish_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["finish_time", b"finish_time", "start_time", b"start_time"]) -> None: ...

global___ScheduleParams = ScheduleParams

@typing.final
class CreateStreamMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___CreateStreamMetadata = CreateStreamMetadata

@typing.final
class UpdateStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STREAM_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ON_DEMAND_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    line_id: builtins.str
    """ID of the line."""
    title: builtins.str
    """Stream title."""
    description: builtins.str
    """Stream description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the stream are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def on_demand(self) -> global___OnDemandParams:
        """On demand stream. It starts immediately when a signal appears."""

    @property
    def schedule(self) -> global___ScheduleParams:
        """Schedule stream. Determines when to start receiving the signal or finish time."""

    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        on_demand: global___OnDemandParams | None = ...,
        schedule: global___ScheduleParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask", "on_demand", b"on_demand", "schedule", b"schedule", "stream_type", b"stream_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "field_mask", b"field_mask", "labels", b"labels", "line_id", b"line_id", "on_demand", b"on_demand", "schedule", b"schedule", "stream_id", b"stream_id", "stream_type", b"stream_type", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["stream_type", b"stream_type"]) -> typing.Literal["on_demand", "schedule"] | None: ...

global___UpdateStreamRequest = UpdateStreamRequest

@typing.final
class UpdateStreamMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___UpdateStreamMetadata = UpdateStreamMetadata

@typing.final
class DeleteStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___DeleteStreamRequest = DeleteStreamRequest

@typing.final
class DeleteStreamMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___DeleteStreamMetadata = DeleteStreamMetadata

@typing.final
class PerformStreamActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    STOP_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    @property
    def publish(self) -> global___PublishAction: ...
    @property
    def stop(self) -> global___StopAction: ...
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        publish: global___PublishAction | None = ...,
        stop: global___StopAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "stop", b"stop"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "stop", b"stop", "stream_id", b"stream_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["publish", "stop"] | None: ...

global___PerformStreamActionRequest = PerformStreamActionRequest

@typing.final
class PublishAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishAction = PublishAction

@typing.final
class StopAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopAction = StopAction

@typing.final
class PerformStreamActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_id", b"stream_id"]) -> None: ...

global___PerformStreamActionMetadata = PerformStreamActionMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_crypto_service.proto\x12(yandex.cloud.kms.v1.asymmetricencryption\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\x18\x41symmetricDecryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nciphertext\x18\x02 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\">\n\x19\x41symmetricDecryptResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\"=\n\x1d\x41symmetricGetPublicKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n\x1e\x41symmetricGetPublicKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t2\xd7\x03\n!AsymmetricEncryptionCryptoService\x12\xd0\x01\n\x07\x44\x65\x63rypt\x12\x42.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptRequest\x1a\x43.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricDecryptResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/kms/v1/asymmetricEncryptionKeys/{key_id}:decrypt:\x01*\x12\xde\x01\n\x0cGetPublicKey\x12G.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyRequest\x1aH.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricGetPublicKeyResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/kms/v1/asymmetricEncryptionKeys/{key_id}/publicKeyBk\n\x17yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_crypto_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kms'
  _ASYMMETRICDECRYPTREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICDECRYPTREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICDECRYPTREQUEST.fields_by_name['ciphertext']._options = None
  _ASYMMETRICDECRYPTREQUEST.fields_by_name['ciphertext']._serialized_options = b'\350\3071\001\212\3101\007<=32768'
  _ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICENCRYPTIONCRYPTOSERVICE.methods_by_name['Decrypt']._options = None
  _ASYMMETRICENCRYPTIONCRYPTOSERVICE.methods_by_name['Decrypt']._serialized_options = b'\202\323\344\223\0026\"1/kms/v1/asymmetricEncryptionKeys/{key_id}:decrypt:\001*'
  _ASYMMETRICENCRYPTIONCRYPTOSERVICE.methods_by_name['GetPublicKey']._options = None
  _ASYMMETRICENCRYPTIONCRYPTOSERVICE.methods_by_name['GetPublicKey']._serialized_options = b'\202\323\344\223\0025\0223/kms/v1/asymmetricEncryptionKeys/{key_id}/publicKey'
  _globals['_ASYMMETRICDECRYPTREQUEST']._serialized_start=190
  _globals['_ASYMMETRICDECRYPTREQUEST']._serialized_end=283
  _globals['_ASYMMETRICDECRYPTRESPONSE']._serialized_start=285
  _globals['_ASYMMETRICDECRYPTRESPONSE']._serialized_end=347
  _globals['_ASYMMETRICGETPUBLICKEYREQUEST']._serialized_start=349
  _globals['_ASYMMETRICGETPUBLICKEYREQUEST']._serialized_end=410
  _globals['_ASYMMETRICGETPUBLICKEYRESPONSE']._serialized_start=412
  _globals['_ASYMMETRICGETPUBLICKEYRESPONSE']._serialized_end=480
  _globals['_ASYMMETRICENCRYPTIONCRYPTOSERVICE']._serialized_start=483
  _globals['_ASYMMETRICENCRYPTIONCRYPTOSERVICE']._serialized_end=954
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RestrictionMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RestrictionValueType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RestrictionValueTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RestrictionMeta._RestrictionValueType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RESTRICTION_VALUE_TYPE_UNSPECIFIED: RestrictionMeta._RestrictionValueType.ValueType  # 0
        BOOLEAN: RestrictionMeta._RestrictionValueType.ValueType  # 1
        LONG: RestrictionMeta._RestrictionValueType.ValueType  # 2
        STRING: RestrictionMeta._RestrictionValueType.ValueType  # 3

    class RestrictionValueType(_RestrictionValueType, metaclass=_RestrictionValueTypeEnumTypeWrapper): ...
    RESTRICTION_VALUE_TYPE_UNSPECIFIED: RestrictionMeta.RestrictionValueType.ValueType  # 0
    BOOLEAN: RestrictionMeta.RestrictionValueType.ValueType  # 1
    LONG: RestrictionMeta.RestrictionValueType.ValueType  # 2
    STRING: RestrictionMeta.RestrictionValueType.ValueType  # 3

    NAME_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of restriction."""
    value_type: global___RestrictionMeta.RestrictionValueType.ValueType
    """Value type of restriction."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value_type: global___RestrictionMeta.RestrictionValueType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "value_type", b"value_type"]) -> None: ...

global___RestrictionMeta = RestrictionMeta

@typing.final
class Restriction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BOOL_VALUE_FIELD_NUMBER: builtins.int
    LONG_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of restriction."""
    @property
    def bool_value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]:
        """List of boolean restriction values. Empty if value type is not boolean."""

    @property
    def long_value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """List of long restriction values. Empty if value type is not long."""

    @property
    def string_value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of string restriction values. Empty if value type is not string."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        bool_value: collections.abc.Iterable[builtins.bool] | None = ...,
        long_value: collections.abc.Iterable[builtins.int] | None = ...,
        string_value: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bool_value", b"bool_value", "long_value", b"long_value", "name", b"name", "string_value", b"string_value"]) -> None: ...

global___Restriction = Restriction

@typing.final
class GetRestrictionsMetaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESTRICTIONS_META_FIELD_NUMBER: builtins.int
    @property
    def restrictions_meta(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RestrictionMeta]:
        """List of restrictions."""

    def __init__(
        self,
        *,
        restrictions_meta: collections.abc.Iterable[global___RestrictionMeta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["restrictions_meta", b"restrictions_meta"]) -> None: ...

global___GetRestrictionsMetaResponse = GetRestrictionsMetaResponse

@typing.final
class RestrictionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESTRICTIONS_FIELD_NUMBER: builtins.int
    @property
    def restrictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Restriction]:
        """List of restrictions."""

    def __init__(
        self,
        *,
        restrictions: collections.abc.Iterable[global___Restriction] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["restrictions", b"restrictions"]) -> None: ...

global___RestrictionsResponse = RestrictionsResponse



from typing import Dict, Optional

from yandex.cloud.iam.v1.iam_token_service_pb2_grpc import IamTokenServiceStub
from yandexcloud._auth_fabric import (
    YC_API_ENDPOINT,
    IamTokenAuth,
    MetadataAuth,
    get_auth_token_requester,
)
from yandexcloud._sdk import SDK


def get_auth_token(
    token: Optional[str] = None,
    service_account_key: Optional[Dict[str, str]] = None,
    iam_token: Optional[str] = None,
    metadata_addr: Optional[str] = None,
    endpoint: Optional[str] = None,
) -> str:
    if endpoint is None:
        endpoint = YC_API_ENDPOINT
    requester = get_auth_token_requester(
        token=token,
        service_account_key=service_account_key,
        iam_token=iam_token,
        metadata_addr=metadata_addr,
        endpoint=endpoint,
    )
    if isinstance(requester, (MetadataAuth, IamTokenAuth)):
        return requester.get_token()

    sdk = SDK()
    client = sdk.client(IamTokenServiceStub)
    return client.Create(requester.get_token_request()).iam_token



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.role_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetRoleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_ID_FIELD_NUMBER: builtins.int
    role_id: builtins.str
    """ID of the Role resource to return.
    To get the role ID, use a [RoleService.List] request.
    """
    def __init__(
        self,
        *,
        role_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["role_id", b"role_id"]) -> None: ...

global___GetRoleRequest = GetRoleRequest

@typing.final
class ListRolesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRolesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListRolesResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListRolesRequest = ListRolesRequest

@typing.final
class ListRolesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRolesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListRolesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.role_pb2.Role]:
        """List of Role resources."""

    def __init__(
        self,
        *,
        roles: collections.abc.Iterable[yandex.cloud.iam.v1.role_pb2.Role] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "roles", b"roles"]) -> None: ...

global___ListRolesResponse = ListRolesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BillableObject(google.protobuf.message.Message):
    """Represents a link to an object in other service.
    This object is being billed in the scope of a billing account.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the object in other service."""
    type: builtins.str
    """Billable object type. Can be one of the following:
    * `cloud`
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

global___BillableObject = BillableObject

@typing.final
class BillableObjectBinding(google.protobuf.message.Message):
    """Represents a binding of the BillableObject to a BillingAccount."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_TIME_FIELD_NUMBER: builtins.int
    BILLABLE_OBJECT_FIELD_NUMBER: builtins.int
    @property
    def effective_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when binding was created."""

    @property
    def billable_object(self) -> global___BillableObject:
        """Object that is bound to billing account."""

    def __init__(
        self,
        *,
        effective_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        billable_object: global___BillableObject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["billable_object", b"billable_object", "effective_time", b"effective_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billable_object", b"billable_object", "effective_time", b"effective_time"]) -> None: ...

global___BillableObjectBinding = BillableObjectBinding



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/thumbnail_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import thumbnail_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/video/v1/thumbnail_service.proto\x12\x15yandex.cloud.video.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a%yandex/cloud/video/v1/thumbnail.proto\"W\n\x14ListThumbnailRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x64 \x01(\x03\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x02\x10\x64\"l\n\x15ListThumbnailResponse\x12\x34\n\nthumbnails\x18\x01 \x03(\x0b\x32 .yandex.cloud.video.v1.Thumbnail\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\",\n\x16\x43reateThumbnailRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"/\n\x17\x43reateThumbnailMetadata\x12\x14\n\x0cthumbnail_id\x18\x01 \x01(\t\"M\n BatchGenerateDownloadURLsRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x15\n\rthumbnail_ids\x18\x02 \x03(\t\"g\n!BatchGenerateDownloadURLsResponse\x12\x42\n\rdownload_urls\x18\x01 \x03(\x0b\x32+.yandex.cloud.video.v1.ThumbnailDownloadURL\"B\n\x14ThumbnailDownloadURL\x12\x14\n\x0cthumbnail_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\"9\n!GenerateThumbnailUploadURLRequest\x12\x14\n\x0cthumbnail_id\x18\x01 \x01(\t\"8\n\"GenerateThumbnailUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t2\x9e\x04\n\x10ThumbnailService\x12\x63\n\x04List\x12+.yandex.cloud.video.v1.ListThumbnailRequest\x1a,.yandex.cloud.video.v1.ListThumbnailResponse\"\x00\x12\x84\x01\n\x06\x43reate\x12-.yandex.cloud.video.v1.CreateThumbnailRequest\x1a!.yandex.cloud.operation.Operation\"(\xb2\xd2*$\n\x17\x43reateThumbnailMetadata\x12\tThumbnail\x12\x90\x01\n\x19\x42\x61tchGenerateDownloadURLs\x12\x37.yandex.cloud.video.v1.BatchGenerateDownloadURLsRequest\x1a\x38.yandex.cloud.video.v1.BatchGenerateDownloadURLsResponse\"\x00\x12\x8a\x01\n\x11GenerateUploadURL\x12\x38.yandex.cloud.video.v1.GenerateThumbnailUploadURLRequest\x1a\x39.yandex.cloud.video.v1.GenerateThumbnailUploadURLResponse\"\x00\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.thumbnail_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _THUMBNAILSERVICE.methods_by_name['Create']._options = None
  _THUMBNAILSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateThumbnailMetadata\022\tThumbnail'
  _globals['_LISTTHUMBNAILREQUEST']._serialized_start=185
  _globals['_LISTTHUMBNAILREQUEST']._serialized_end=272
  _globals['_LISTTHUMBNAILRESPONSE']._serialized_start=274
  _globals['_LISTTHUMBNAILRESPONSE']._serialized_end=382
  _globals['_CREATETHUMBNAILREQUEST']._serialized_start=384
  _globals['_CREATETHUMBNAILREQUEST']._serialized_end=428
  _globals['_CREATETHUMBNAILMETADATA']._serialized_start=430
  _globals['_CREATETHUMBNAILMETADATA']._serialized_end=477
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST']._serialized_start=479
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST']._serialized_end=556
  _globals['_BATCHGENERATEDOWNLOADURLSRESPONSE']._serialized_start=558
  _globals['_BATCHGENERATEDOWNLOADURLSRESPONSE']._serialized_end=661
  _globals['_THUMBNAILDOWNLOADURL']._serialized_start=663
  _globals['_THUMBNAILDOWNLOADURL']._serialized_end=729
  _globals['_GENERATETHUMBNAILUPLOADURLREQUEST']._serialized_start=731
  _globals['_GENERATETHUMBNAILUPLOADURLREQUEST']._serialized_end=788
  _globals['_GENERATETHUMBNAILUPLOADURLRESPONSE']._serialized_start=790
  _globals['_GENERATETHUMBNAILUPLOADURLRESPONSE']._serialized_end=846
  _globals['_THUMBNAILSERVICE']._serialized_start=849
  _globals['_THUMBNAILSERVICE']._serialized_end=1391
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.agent.status_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Agent(google.protobuf.message.Message):
    """Load testing agent on which tests are executed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    CURRENT_JOB_ID_FIELD_NUMBER: builtins.int
    AGENT_VERSION_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the agent. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the agent belongs to."""
    name: builtins.str
    """Name of the agent."""
    description: builtins.str
    """Description of the agent."""
    compute_instance_id: builtins.str
    """ID of the compute instance managed by the agent.

    Empty if there is no such instance (i.e. the case of external agent).
    """
    status: yandex.cloud.loadtesting.api.v1.agent.status_pb2.Status.ValueType
    """Status of the agent."""
    current_job_id: builtins.str
    """ID of the test that is currently being executed by the agent."""
    agent_version_id: builtins.str
    """Version of the agent."""
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of errors reported by the agent."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Agent labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        status: yandex.cloud.loadtesting.api.v1.agent.status_pb2.Status.ValueType = ...,
        errors: collections.abc.Iterable[builtins.str] | None = ...,
        current_job_id: builtins.str = ...,
        agent_version_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_version_id", b"agent_version_id", "compute_instance_id", b"compute_instance_id", "current_job_id", b"current_job_id", "description", b"description", "errors", b"errors", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "status", b"status"]) -> None: ...

global___Agent = Agent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.dataproc.v1.subcluster_pb2
import yandex.cloud.dataproc.v1.subcluster_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SubclusterServiceStub:
    """A set of methods for managing Data Proc subclusters."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.GetSubclusterRequest,
        yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster,
    ]
    """Returns the specified subcluster.

    To get the list of all available subclusters, make a [SubclusterService.List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersRequest,
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse,
    ]
    """Retrieves a list of subclusters in the specified cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.CreateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a subcluster in the specified cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.UpdateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified subcluster."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.DeleteSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified subcluster."""

class SubclusterServiceAsyncStub:
    """A set of methods for managing Data Proc subclusters."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.GetSubclusterRequest,
        yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster,
    ]
    """Returns the specified subcluster.

    To get the list of all available subclusters, make a [SubclusterService.List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersRequest,
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse,
    ]
    """Retrieves a list of subclusters in the specified cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.CreateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a subcluster in the specified cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.UpdateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified subcluster."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.DeleteSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified subcluster."""

class SubclusterServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Data Proc subclusters."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.GetSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster, collections.abc.Awaitable[yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster]]:
        """Returns the specified subcluster.

        To get the list of all available subclusters, make a [SubclusterService.List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse, collections.abc.Awaitable[yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse]]:
        """Retrieves a list of subclusters in the specified cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.CreateSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a subcluster in the specified cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.UpdateSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified subcluster."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.DeleteSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified subcluster."""

def add_SubclusterServiceServicer_to_server(servicer: SubclusterServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FileCompressionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileCompressionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileCompressionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FILE_COMPRESSION_TYPE_UNSPECIFIED: _FileCompressionType.ValueType  # 0
    NONE: _FileCompressionType.ValueType  # 1
    ZIP: _FileCompressionType.ValueType  # 2

class FileCompressionType(_FileCompressionType, metaclass=_FileCompressionTypeEnumTypeWrapper): ...

FILE_COMPRESSION_TYPE_UNSPECIFIED: FileCompressionType.ValueType  # 0
NONE: FileCompressionType.ValueType  # 1
ZIP: FileCompressionType.ValueType  # 2
global___FileCompressionType = FileCompressionType

class _JobStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _JobStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_JobStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JOB_STATUS_UNSPECIFIED: _JobStatus.ValueType  # 0
    CREATING: _JobStatus.ValueType  # 1
    EXECUTING: _JobStatus.ValueType  # 2
    UPLOADING_OUTPUT: _JobStatus.ValueType  # 3
    SUCCESS: _JobStatus.ValueType  # 4
    ERROR: _JobStatus.ValueType  # 5
    CANCELLED: _JobStatus.ValueType  # 6

class JobStatus(_JobStatus, metaclass=_JobStatusEnumTypeWrapper): ...

JOB_STATUS_UNSPECIFIED: JobStatus.ValueType  # 0
CREATING: JobStatus.ValueType  # 1
EXECUTING: JobStatus.ValueType  # 2
UPLOADING_OUTPUT: JobStatus.ValueType  # 3
SUCCESS: JobStatus.ValueType  # 4
ERROR: JobStatus.ValueType  # 5
CANCELLED: JobStatus.ValueType  # 6
global___JobStatus = JobStatus

@typing.final
class JobParameters(google.protobuf.message.Message):
    """Job parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_FILES_FIELD_NUMBER: builtins.int
    OUTPUT_FILES_FIELD_NUMBER: builtins.int
    S3_MOUNT_IDS_FIELD_NUMBER: builtins.int
    DATASET_IDS_FIELD_NUMBER: builtins.int
    CMD_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ATTACH_PROJECT_DISK_FIELD_NUMBER: builtins.int
    CLOUD_INSTANCE_TYPES_FIELD_NUMBER: builtins.int
    EXTENDED_WORKING_STORAGE_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    OUTPUT_DATASETS_FIELD_NUMBER: builtins.int
    GRACEFUL_SHUTDOWN_PARAMETERS_FIELD_NUMBER: builtins.int
    cmd: builtins.str
    """Job run command."""
    attach_project_disk: builtins.bool
    """Should project disk be attached to VM."""
    @property
    def input_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """List of input files."""

    @property
    def output_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FileDesc]:
        """List of output files descriptions."""

    @property
    def s3_mount_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of DataSphere S3 mount ids."""

    @property
    def dataset_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of DataSphere dataset ids."""

    @property
    def env(self) -> global___Environment:
        """Job environment description."""

    @property
    def cloud_instance_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudInstanceType]:
        """VM specification."""

    @property
    def extended_working_storage(self) -> global___ExtendedWorkingStorage:
        """Extended working storage configuration."""

    @property
    def arguments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Argument]:
        """List of literal arguments."""

    @property
    def output_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OutputDatasetDesc]:
        """List of DataSets descriptions to create"""

    @property
    def graceful_shutdown_parameters(self) -> global___GracefulShutdownParameters: ...
    def __init__(
        self,
        *,
        input_files: collections.abc.Iterable[global___File] | None = ...,
        output_files: collections.abc.Iterable[global___FileDesc] | None = ...,
        s3_mount_ids: collections.abc.Iterable[builtins.str] | None = ...,
        dataset_ids: collections.abc.Iterable[builtins.str] | None = ...,
        cmd: builtins.str = ...,
        env: global___Environment | None = ...,
        attach_project_disk: builtins.bool = ...,
        cloud_instance_types: collections.abc.Iterable[global___CloudInstanceType] | None = ...,
        extended_working_storage: global___ExtendedWorkingStorage | None = ...,
        arguments: collections.abc.Iterable[global___Argument] | None = ...,
        output_datasets: collections.abc.Iterable[global___OutputDatasetDesc] | None = ...,
        graceful_shutdown_parameters: global___GracefulShutdownParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["env", b"env", "extended_working_storage", b"extended_working_storage", "graceful_shutdown_parameters", b"graceful_shutdown_parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "attach_project_disk", b"attach_project_disk", "cloud_instance_types", b"cloud_instance_types", "cmd", b"cmd", "dataset_ids", b"dataset_ids", "env", b"env", "extended_working_storage", b"extended_working_storage", "graceful_shutdown_parameters", b"graceful_shutdown_parameters", "input_files", b"input_files", "output_datasets", b"output_datasets", "output_files", b"output_files", "s3_mount_ids", b"s3_mount_ids"]) -> None: ...

global___JobParameters = JobParameters

@typing.final
class CloudInstanceType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of DataSphere VM configuration."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___CloudInstanceType = CloudInstanceType

@typing.final
class ExtendedWorkingStorage(google.protobuf.message.Message):
    """Extended working storage configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _StorageType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StorageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExtendedWorkingStorage._StorageType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STORAGE_TYPE_UNSPECIFIED: ExtendedWorkingStorage._StorageType.ValueType  # 0
        SSD: ExtendedWorkingStorage._StorageType.ValueType  # 1

    class StorageType(_StorageType, metaclass=_StorageTypeEnumTypeWrapper): ...
    STORAGE_TYPE_UNSPECIFIED: ExtendedWorkingStorage.StorageType.ValueType  # 0
    SSD: ExtendedWorkingStorage.StorageType.ValueType  # 1

    TYPE_FIELD_NUMBER: builtins.int
    SIZE_GB_FIELD_NUMBER: builtins.int
    type: global___ExtendedWorkingStorage.StorageType.ValueType
    size_gb: builtins.int
    def __init__(
        self,
        *,
        type: global___ExtendedWorkingStorage.StorageType.ValueType = ...,
        size_gb: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["size_gb", b"size_gb", "type", b"type"]) -> None: ...

global___ExtendedWorkingStorage = ExtendedWorkingStorage

@typing.final
class Argument(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

global___Argument = Argument

@typing.final
class File(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    sha256: builtins.str
    """SHA256 of the file."""
    size_bytes: builtins.int
    """File size in bytes."""
    compression_type: global___FileCompressionType.ValueType
    """File compression info"""
    @property
    def desc(self) -> global___FileDesc: ...
    def __init__(
        self,
        *,
        desc: global___FileDesc | None = ...,
        sha256: builtins.str = ...,
        size_bytes: builtins.int = ...,
        compression_type: global___FileCompressionType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["desc", b"desc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compression_type", b"compression_type", "desc", b"desc", "sha256", b"sha256", "size_bytes", b"size_bytes"]) -> None: ...

global___File = File

@typing.final
class StorageFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """File URL."""
    @property
    def file(self) -> global___File: ...
    def __init__(
        self,
        *,
        file: global___File | None = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "url", b"url"]) -> None: ...

global___StorageFile = StorageFile

@typing.final
class FileDesc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    VAR_FIELD_NUMBER: builtins.int
    path: builtins.str
    """Path of the file on filesystem."""
    var: builtins.str
    """Variable to use in cmd substitution."""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        var: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path", "var", b"var"]) -> None: ...

global___FileDesc = FileDesc

@typing.final
class Environment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class VarsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    VARS_FIELD_NUMBER: builtins.int
    DOCKER_IMAGE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    DOCKER_IMAGE_SPEC_FIELD_NUMBER: builtins.int
    PYTHON_ENV_FIELD_NUMBER: builtins.int
    docker_image_resource_id: builtins.str
    """DS docker image id."""
    @property
    def vars(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Environment variables."""

    @property
    def docker_image_spec(self) -> global___DockerImageSpec: ...
    @property
    def python_env(self) -> global___PythonEnv: ...
    def __init__(
        self,
        *,
        vars: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        docker_image_resource_id: builtins.str = ...,
        docker_image_spec: global___DockerImageSpec | None = ...,
        python_env: global___PythonEnv | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["docker_image", b"docker_image", "docker_image_resource_id", b"docker_image_resource_id", "docker_image_spec", b"docker_image_spec", "python_env", b"python_env"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["docker_image", b"docker_image", "docker_image_resource_id", b"docker_image_resource_id", "docker_image_spec", b"docker_image_spec", "python_env", b"python_env", "vars", b"vars"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["docker_image", b"docker_image"]) -> typing.Literal["docker_image_resource_id", "docker_image_spec"] | None: ...

global___Environment = Environment

@typing.final
class DockerImageSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_PLAIN_TEXT_FIELD_NUMBER: builtins.int
    PASSWORD_DS_SECRET_NAME_FIELD_NUMBER: builtins.int
    image_url: builtins.str
    """Docker image URL."""
    username: builtins.str
    """Username for container registry."""
    password_plain_text: builtins.str
    """Plaintext password."""
    password_ds_secret_name: builtins.str
    """ID of DataSphere secret containing password."""
    def __init__(
        self,
        *,
        image_url: builtins.str = ...,
        username: builtins.str = ...,
        password_plain_text: builtins.str = ...,
        password_ds_secret_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password", b"password", "password_ds_secret_name", b"password_ds_secret_name", "password_plain_text", b"password_plain_text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["image_url", b"image_url", "password", b"password", "password_ds_secret_name", b"password_ds_secret_name", "password_plain_text", b"password_plain_text", "username", b"username"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["password", b"password"]) -> typing.Literal["password_plain_text", "password_ds_secret_name"] | None: ...

global___DockerImageSpec = DockerImageSpec

@typing.final
class PythonEnv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDA_YAML_FIELD_NUMBER: builtins.int
    LOCAL_MODULES_FIELD_NUMBER: builtins.int
    conda_yaml: builtins.str
    """Conda YAML."""
    @property
    def local_modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """List of local modules descriptions."""

    def __init__(
        self,
        *,
        conda_yaml: builtins.str = ...,
        local_modules: collections.abc.Iterable[global___File] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conda_yaml", b"conda_yaml", "local_modules", b"local_modules"]) -> None: ...

global___PythonEnv = PythonEnv

@typing.final
class OutputDatasetDesc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SIZE_GB_FIELD_NUMBER: builtins.int
    VAR_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name to create dataset with"""
    description: builtins.str
    """Description to show in UI"""
    size_gb: builtins.int
    """Size of dataset to create"""
    var: builtins.str
    """Var name to replace in cmd, like in FileDesc"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        size_gb: builtins.int = ...,
        var: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "size_gb", b"size_gb", "var", b"var"]) -> None: ...

global___OutputDatasetDesc = OutputDatasetDesc

@typing.final
class OutputDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Id of created dataset"""
    @property
    def desc(self) -> global___OutputDatasetDesc:
        """Dataset description"""

    def __init__(
        self,
        *,
        desc: global___OutputDatasetDesc | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["desc", b"desc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desc", b"desc", "id", b"id"]) -> None: ...

global___OutputDataset = OutputDataset

@typing.final
class Job(google.protobuf.message.Message):
    """Instance of the job."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    CREATED_BY_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    JOB_PARAMETERS_FIELD_NUMBER: builtins.int
    DATA_EXPIRES_AT_FIELD_NUMBER: builtins.int
    DATA_CLEARED_FIELD_NUMBER: builtins.int
    OUTPUT_FILES_FIELD_NUMBER: builtins.int
    LOG_FILES_FIELD_NUMBER: builtins.int
    DIAGNOSTIC_FILES_FIELD_NUMBER: builtins.int
    DATA_SIZE_BYTES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the job."""
    name: builtins.str
    """Name of the job."""
    desc: builtins.str
    """Description of the job."""
    status: global___JobStatus.ValueType
    """Status of the job."""
    config: builtins.str
    """Config of the job, copied from configuration file."""
    created_by_id: builtins.str
    """ID of the user who created the job."""
    project_id: builtins.str
    """ID of the project."""
    data_cleared: builtins.bool
    """Marks if the job data has been cleared."""
    data_size_bytes: builtins.int
    """Job total data size."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Create job timestamp."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start job timestamp."""

    @property
    def finished_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Finish job timestamp."""

    @property
    def job_parameters(self) -> global___JobParameters: ...
    @property
    def data_expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Job data expiration timestamp."""

    @property
    def output_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """Output files of the job."""

    @property
    def log_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """Job log files."""

    @property
    def diagnostic_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """Job diagnostics files."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        desc: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finished_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___JobStatus.ValueType = ...,
        config: builtins.str = ...,
        created_by_id: builtins.str = ...,
        project_id: builtins.str = ...,
        job_parameters: global___JobParameters | None = ...,
        data_expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        data_cleared: builtins.bool = ...,
        output_files: collections.abc.Iterable[global___File] | None = ...,
        log_files: collections.abc.Iterable[global___File] | None = ...,
        diagnostic_files: collections.abc.Iterable[global___File] | None = ...,
        data_size_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "data_expires_at", b"data_expires_at", "finished_at", b"finished_at", "job_parameters", b"job_parameters", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "created_by_id", b"created_by_id", "data_cleared", b"data_cleared", "data_expires_at", b"data_expires_at", "data_size_bytes", b"data_size_bytes", "desc", b"desc", "diagnostic_files", b"diagnostic_files", "finished_at", b"finished_at", "id", b"id", "job_parameters", b"job_parameters", "log_files", b"log_files", "name", b"name", "output_files", b"output_files", "project_id", b"project_id", "started_at", b"started_at", "status", b"status"]) -> None: ...

global___Job = Job

@typing.final
class JobResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURN_CODE_FIELD_NUMBER: builtins.int
    return_code: builtins.int
    """Execution return code."""
    def __init__(
        self,
        *,
        return_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["return_code", b"return_code"]) -> None: ...

global___JobResult = JobResult

@typing.final
class GracefulShutdownParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMEOUT_FIELD_NUMBER: builtins.int
    SIGNAL_FIELD_NUMBER: builtins.int
    signal: builtins.int
    """default 15 (SIGTERM)"""
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        signal: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["signal", b"signal", "timeout", b"timeout"]) -> None: ...

global___GracefulShutdownParameters = GracefulShutdownParameters



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SilenceStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_SIMULTANEOUS_SILENCE_DURATION_MS_FIELD_NUMBER: builtins.int
    TOTAL_SIMULTANEOUS_SILENCE_RATIO_FIELD_NUMBER: builtins.int
    SIMULTANEOUS_SILENCE_DURATION_ESTIMATION_FIELD_NUMBER: builtins.int
    TOTAL_SIMULTANEOUS_SILENCE_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    total_simultaneous_silence_duration_ms: builtins.int
    total_simultaneous_silence_ratio: builtins.float
    """Simultaneous silence ratio within audio segment"""
    total_simultaneous_silence_duration_seconds: builtins.int
    @property
    def simultaneous_silence_duration_estimation(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics:
        """Descriptive statistics for simultaneous silence duration distribution"""

    def __init__(
        self,
        *,
        total_simultaneous_silence_duration_ms: builtins.int = ...,
        total_simultaneous_silence_ratio: builtins.float = ...,
        simultaneous_silence_duration_estimation: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics | None = ...,
        total_simultaneous_silence_duration_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["simultaneous_silence_duration_estimation", b"simultaneous_silence_duration_estimation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["simultaneous_silence_duration_estimation", b"simultaneous_silence_duration_estimation", "total_simultaneous_silence_duration_ms", b"total_simultaneous_silence_duration_ms", "total_simultaneous_silence_duration_seconds", b"total_simultaneous_silence_duration_seconds", "total_simultaneous_silence_ratio", b"total_simultaneous_silence_ratio"]) -> None: ...

global___SilenceStatistics = SilenceStatistics



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.address_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetAddressRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the Address resource to return.

    To get Address resource ID make a [AddressService.List] request.
    """
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id"]) -> None: ...

global___GetAddressRequest = GetAddressRequest

@typing.final
class GetAddressByValueRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    external_ipv4_address: builtins.str
    def __init__(
        self,
        *,
        external_ipv4_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "external_ipv4_address", b"external_ipv4_address"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "external_ipv4_address", b"external_ipv4_address"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["external_ipv4_address"] | None: ...

global___GetAddressByValueRequest = GetAddressByValueRequest

@typing.final
class ListAddressesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list addresses in.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListAddressesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListAddressesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters Address listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [Address.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-address`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAddressesRequest = ListAddressesRequest

@typing.final
class ListAddressesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESSES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListAddressesRequest.page_size], use `next_page_token` as the value
    for the [ListAddressesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.address_pb2.Address]:
        """List of addresses."""

    def __init__(
        self,
        *,
        addresses: collections.abc.Iterable[yandex.cloud.vpc.v1.address_pb2.Address] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["addresses", b"addresses", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAddressesResponse = ListAddressesResponse

@typing.final
class CreateAddressRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DNS_RECORD_SPECS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a address in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the address.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the address."""
    deletion_protection: builtins.bool
    """Specifies if address protected from deletion."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Address labels as `key:value` pairs."""

    @property
    def external_ipv4_address_spec(self) -> global___ExternalIpv4AddressSpec: ...
    @property
    def dns_record_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecordSpec]:
        """Optional DNS record specifications"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        external_ipv4_address_spec: global___ExternalIpv4AddressSpec | None = ...,
        deletion_protection: builtins.bool = ...,
        dns_record_specs: collections.abc.Iterable[global___DnsRecordSpec] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address_spec", b"address_spec", "external_ipv4_address_spec", b"external_ipv4_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address_spec", b"address_spec", "deletion_protection", b"deletion_protection", "description", b"description", "dns_record_specs", b"dns_record_specs", "external_ipv4_address_spec", b"external_ipv4_address_spec", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address_spec", b"address_spec"]) -> typing.Literal["external_ipv4_address_spec"] | None: ...

global___CreateAddressRequest = CreateAddressRequest

@typing.final
class ExternalIpv4AddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    REQUIREMENTS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """Value of address.
    if unspecified, one will be automatically allocated from other params
    """
    zone_id: builtins.str
    """Availability zone from which the address will be allocated.
    only if address unspecified
    """
    @property
    def requirements(self) -> yandex.cloud.vpc.v1.address_pb2.AddressRequirements:
        """Parameters of the allocated address, for example DDoS Protection."""

    def __init__(
        self,
        *,
        address: builtins.str = ...,
        zone_id: builtins.str = ...,
        requirements: yandex.cloud.vpc.v1.address_pb2.AddressRequirements | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["requirements", b"requirements"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "requirements", b"requirements", "zone_id", b"zone_id"]) -> None: ...

global___ExternalIpv4AddressSpec = ExternalIpv4AddressSpec

@typing.final
class DnsRecordSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    PTR_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    """Required. DNS record name (absolute or relative to the DNS zone in use)."""
    dns_zone_id: builtins.str
    """Required. ID of the public DNS zone. The maximum string length in characters is 20."""
    ttl: builtins.int
    """TTL of record. Acceptable values are 0 to 86400, inclusive."""
    ptr: builtins.bool
    """Optional. If the PTR record is required, this parameter must be set to "true"."""
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        dns_zone_id: builtins.str = ...,
        ttl: builtins.int = ...,
        ptr: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "fqdn", b"fqdn", "ptr", b"ptr", "ttl", b"ttl"]) -> None: ...

global___DnsRecordSpec = DnsRecordSpec

@typing.final
class CreateAddressMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the address that is being created."""
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id"]) -> None: ...

global___CreateAddressMetadata = CreateAddressMetadata

@typing.final
class UpdateAddressRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RESERVED_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DNS_RECORD_SPECS_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the address to update.

    To get the address ID make a [AddressService.List] request.
    """
    name: builtins.str
    """New name for the address.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the address."""
    reserved: builtins.bool
    """Specifies if address is reserved or not."""
    deletion_protection: builtins.bool
    """Specifies if address protected from deletion."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the Address should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Address labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [AddressService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def dns_record_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecordSpec]:
        """Optional DNS record specifications"""

    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        reserved: builtins.bool = ...,
        deletion_protection: builtins.bool = ...,
        dns_record_specs: collections.abc.Iterable[global___DnsRecordSpec] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id", "deletion_protection", b"deletion_protection", "description", b"description", "dns_record_specs", b"dns_record_specs", "labels", b"labels", "name", b"name", "reserved", b"reserved", "update_mask", b"update_mask"]) -> None: ...

global___UpdateAddressRequest = UpdateAddressRequest

@typing.final
class UpdateAddressMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the Address that is being updated."""
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id"]) -> None: ...

global___UpdateAddressMetadata = UpdateAddressMetadata

@typing.final
class DeleteAddressRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the address to delete.

    To get a address ID make a [AddressService.List] request.
    """
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id"]) -> None: ...

global___DeleteAddressRequest = DeleteAddressRequest

@typing.final
class DeleteAddressMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the address that is being deleted."""
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id"]) -> None: ...

global___DeleteAddressMetadata = DeleteAddressMetadata

@typing.final
class ListAddressOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the address to list operations for.

    To get a address ID make a [AddressService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListAddressOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListAddressOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAddressOperationsRequest = ListAddressOperationsRequest

@typing.final
class ListAddressOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListAddressOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListAddressOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified address."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListAddressOperationsResponse = ListAddressOperationsResponse

@typing.final
class MoveAddressRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the address that is being moved."""
    destination_folder_id: builtins.str
    """ID of the folder to move address to."""
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id", "destination_folder_id", b"destination_folder_id"]) -> None: ...

global___MoveAddressRequest = MoveAddressRequest

@typing.final
class MoveAddressMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_ID_FIELD_NUMBER: builtins.int
    address_id: builtins.str
    """ID of the address that is being moved."""
    def __init__(
        self,
        *,
        address_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address_id", b"address_id"]) -> None: ...

global___MoveAddressMetadata = MoveAddressMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ClassificationLabel(google.protobuf.message.Message):
    """A pair of text label and corresponding confidence used in classification problems."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    label: builtins.str
    """A label with a class name."""
    confidence: builtins.float
    """Confidence of item's belonging to a class."""
    def __init__(
        self,
        *,
        label: builtins.str = ...,
        confidence: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "label", b"label"]) -> None: ...

global___ClassificationLabel = ClassificationLabel

@typing.final
class ClassificationSample(google.protobuf.message.Message):
    """Description of a sample for the classification task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text sample."""
    label: builtins.str
    """Expected label for a given text."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        label: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["label", b"label", "text", b"text"]) -> None: ...

global___ClassificationSample = ClassificationSample
